[![Travis](https://img.shields.io/travis/RegiusQuant/regius.svg?label=Travis%20CI)](https://travis-ci.org/RegiusQuant/regius)
[![PyPi](https://img.shields.io/pypi/v/regius-dl.svg)](https://pypi.org/project/regius-dl/)

[![Python Version](https://img.shields.io/pypi/pyversions/regius-dl.svg)](https://pypi.org/project/regius-dl/)
[![License](https://img.shields.io/pypi/l/regius-dl.svg)](https://pypi.org/project/regius-dl/)

# Regius
Regius DL/ML Toolbox
